package com.example;

import com.huawei.huaweichain.contract.Contract;
import com.huawei.huaweichain.contract.ContractException;
import com.huawei.huaweichain.contract.ContractStub;
import com.huawei.huaweichain.contract.impl.Process;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class Main implements Contract {
    public static final Logger logger = LoggerFactory.getLogger(Main.class);

    public Main() {
    }

    public byte[] init(ContractStub stub) throws ContractException {
        stub.putKv("initial_state", "hello world".getBytes());
        return "success".getBytes();
    }

    public byte[] invoke(ContractStub stub) throws ContractException {
        String func = stub.funcName();
        byte[][] args = stub.parameters();
        switch (func) {
            case "insert":
                return this.insert(stub, args);
            case "query":
                return this.query(stub, args);
            default:
                throw new ContractException("unsupported function");
        }
    }

    private byte[] insert(ContractStub stub, byte[][] args) throws ContractException {
        String key = new String(args[0]);
        byte[] val = args[1];
        stub.putKv(key, val);
        return new byte[0];
    }

    private byte[] query(ContractStub stub, byte[][] args) throws ContractException {
        String key = new String(args[0]);
        return stub.getKv(key);
    }

    public static void main(String[] args) {
        try {
            Contract contract = new Main();
            Process.start(contract);
        } catch (ContractException contractException) {
            logger.error("failed to start contract, caused by:", contractException);
            throw new RuntimeException(contractException);
        }
    }
}
